@@ -96,6 +96,11 @@ def stringtopretty(timestring):
 	"""Return pretty version of time given w3 time string"""
 	return timetopretty(stringtotime(timestring))
 
+def prettytotime(prettystring):
+	"""Converts time like "Mon Jun 5 11:00:23" to epoch sec, or None"""
+	try: return time.mktime(time.strptime(prettystring))
+	except ValueError: return None
+
 def inttopretty(seconds):
 	"""Convert num of seconds to readable string like "2 hours"."""
 	partlist = []
@@ -187,7 +192,7 @@ def time_from_session(session_num, rp = None):
 	session_times = Globals.rbdir.conn.restore.MirrorStruct \
 					.get_increment_times()
 	session_times.sort()
-	if len(session_times) < session_num:
+	if len(session_times) <= session_num:
 		return session_times[0] # Use oldest if two few backups
 	return session_times[-session_num-1]
 	
@@ -222,6 +227,10 @@ the day).""" % timestr)
 	if _session_regexp.search(timestr):
 		return time_from_session(int(timestr[:-1]), rp)
 
+	# Try for long time, like "Mon Jun 5 11:00:23 1990"
+	t = prettytotime(timestr)
+	if t is not None: return t
+
 	try: # test for an interval, like "2 days ago"
 		return curtime - intstringtoseconds(timestr)
 	except TimeException: pass
